StorageBasic

Struct StorageBasic 

pub struct StorageBasic {
Show 24 fields pub w_cha_max: u16, pub w_cha_gra: u16, pub w_dis_cha_gra: u16, pub stor_ctl_mod: StorCtlMod, pub va_cha_max: Option<u16>, pub min_rsv_pct: Option<u16>, pub cha_state: Option<u16>, pub stor_aval: Option<u16>, pub in_bat_v: Option<u16>, pub cha_st: Option<ChaSt>, pub out_w_rte: Option<i16>, pub in_w_rte: Option<i16>, pub in_out_w_rte_win_tms: Option<u16>, pub in_out_w_rte_rvrt_tms: Option<u16>, pub in_out_w_rte_rmp_tms: Option<u16>, pub cha_gri_set: Option<ChaGriSet>, pub w_cha_max_sf: i16, pub w_cha_dis_cha_gra_sf: i16, pub va_cha_max_sf: Option<i16>, pub min_rsv_pct_sf: Option<i16>, pub cha_state_sf: Option<i16>, pub stor_aval_sf: Option<i16>, pub in_bat_v_sf: Option<i16>, pub in_out_w_rte_sf: Option<i16>,
}
Available on crate feature model124 only.
Storage

Basic Storage Controls

Detail: Ref 3: 8.7.4.2

Fields

w_cha_max: u16

WChaMax

Setpoint for maximum charge.

w_cha_gra: u16

WChaGra

Setpoint for maximum charging rate. Default is MaxChaRte.

w_dis_cha_gra: u16

WDisChaGra

Setpoint for maximum discharge rate. Default is MaxDisChaRte.

stor_ctl_mod: StorCtlMod

StorCtl_Mod

Activate hold/discharge/charge storage control mode. Bitfield value.

va_cha_max: Option<u16>

VAChaMax

Setpoint for maximum charging VA.

min_rsv_pct: Option<u16>

MinRsvPct

Setpoint for minimum reserve for storage as a percentage of the nominal maximum storage.

cha_state: Option<u16>

ChaState

Currently available energy as a percent of the capacity rating.

stor_aval: Option<u16>

StorAval

State of charge (ChaState) minus storage reserve (MinRsvPct) times capacity rating (AhrRtg).

in_bat_v: Option<u16>

InBatV

Internal battery voltage.

cha_st: Option<ChaSt>

ChaSt

Charge status of storage device. Enumerated value.

out_w_rte: Option<i16>

OutWRte

Percent of max discharge rate.

in_w_rte: Option<i16>

InWRte

Percent of max charging rate.

in_out_w_rte_win_tms: Option<u16>

InOutWRte_WinTms

Time window for charge/discharge rate change.

in_out_w_rte_rvrt_tms: Option<u16>

InOutWRte_RvrtTms

Timeout period for charge/discharge rate.

in_out_w_rte_rmp_tms: Option<u16>

InOutWRte_RmpTms

Ramp time for moving from current setpoint to new setpoint.

cha_gri_set: Option<ChaGriSet>w_cha_max_sf: i16

WChaMax_SF

Scale factor for maximum charge.

w_cha_dis_cha_gra_sf: i16

WChaDisChaGra_SF

Scale factor for maximum charge and discharge rate.

va_cha_max_sf: Option<i16>

VAChaMax_SF

Scale factor for maximum charging VA.

min_rsv_pct_sf: Option<i16>

MinRsvPct_SF

Scale factor for minimum reserve percentage.

cha_state_sf: Option<i16>

ChaState_SF

Scale factor for available energy percent.

stor_aval_sf: Option<i16>

StorAval_SF

Scale factor for state of charge.

in_bat_v_sf: Option<i16>

InBatV_SF

Scale factor for battery voltage.

in_out_w_rte_sf: Option<i16>

InOutWRte_SF

Scale factor for percent charge/discharge rate.

Implementations

Source

impl StorageBasic

pub const W_CHA_MAX: Point<Self, u16>

pub const W_CHA_GRA: Point<Self, u16>

pub const W_DIS_CHA_GRA: Point<Self, u16>

pub const STOR_CTL_MOD: Point<Self, StorCtlMod>

pub const VA_CHA_MAX: Point<Self, Option<u16>>

pub const MIN_RSV_PCT: Point<Self, Option<u16>>

pub const CHA_STATE: Point<Self, Option<u16>>

pub const STOR_AVAL: Point<Self, Option<u16>>

pub const IN_BAT_V: Point<Self, Option<u16>>

pub const CHA_ST: Point<Self, Option<ChaSt>>

pub const OUT_W_RTE: Point<Self, Option<i16>>

pub const IN_W_RTE: Point<Self, Option<i16>>

pub const IN_OUT_W_RTE_WIN_TMS: Point<Self, Option<u16>>

pub const IN_OUT_W_RTE_RVRT_TMS: Point<Self, Option<u16>>

pub const IN_OUT_W_RTE_RMP_TMS: Point<Self, Option<u16>>

pub const CHA_GRI_SET: Point<Self, Option<ChaGriSet>>

pub const W_CHA_MAX_SF: Point<Self, i16>

pub const W_CHA_DIS_CHA_GRA_SF: Point<Self, i16>

pub const VA_CHA_MAX_SF: Point<Self, Option<i16>>

pub const MIN_RSV_PCT_SF: Point<Self, Option<i16>>

pub const CHA_STATE_SF: Point<Self, Option<i16>>

pub const STOR_AVAL_SF: Point<Self, Option<i16>>

pub const IN_BAT_V_SF: Point<Self, Option<i16>>

pub const IN_OUT_W_RTE_SF: Point<Self, Option<i16>>