Curve

Struct Curve 

pub struct Curve {
Show 47 fields pub act_pt: u16, pub dept_ref: CurveDeptRef, pub v1: u16, pub v_ar1: i16, pub v2: Option<u16>, pub v_ar2: Option<i16>, pub v3: Option<u16>, pub v_ar3: Option<i16>, pub v4: Option<u16>, pub v_ar4: Option<i16>, pub v5: Option<u16>, pub v_ar5: Option<i16>, pub v6: Option<u16>, pub v_ar6: Option<i16>, pub v7: Option<u16>, pub v_ar7: Option<i16>, pub v8: Option<u16>, pub v_ar8: Option<i16>, pub v9: Option<u16>, pub v_ar9: Option<i16>, pub v10: Option<u16>, pub v_ar10: Option<i16>, pub v11: Option<u16>, pub v_ar11: Option<i16>, pub v12: Option<u16>, pub v_ar12: Option<i16>, pub v13: Option<u16>, pub v_ar13: Option<i16>, pub v14: Option<u16>, pub v_ar14: Option<i16>, pub v15: Option<u16>, pub v_ar15: Option<i16>, pub v16: Option<u16>, pub v_ar16: Option<i16>, pub v17: Option<u16>, pub v_ar17: Option<i16>, pub v18: Option<u16>, pub v_ar18: Option<i16>, pub v19: Option<u16>, pub v_ar19: Option<i16>, pub v20: Option<u16>, pub v_ar20: Option<i16>, pub crv_nam: Option<String>, pub rmp_tms: Option<u16>, pub rmp_dec_tmm: Option<u16>, pub rmp_inc_tmm: Option<u16>, pub read_only: CurveReadOnly,
}
Available on crate feature model126 only.

Fields

act_pt: u16

ActPt

Number of active points in array.

dept_ref: CurveDeptRef

DeptRef

Meaning of dependent variable: 1=%WMax 2=%VArMax 3=%VArAval.

v1: u16

V1

Point 1 Volts.

v_ar1: i16

VAr1

Point 1 VARs.

v2: Option<u16>

V2

Point 2 Volts.

v_ar2: Option<i16>

VAr2

Point 2 VARs.

v3: Option<u16>

V3

Point 3 Volts.

v_ar3: Option<i16>

VAr3

Point 3 VARs.

v4: Option<u16>

V4

Point 4 Volts.

v_ar4: Option<i16>

VAr4

Point 4 VARs.

v5: Option<u16>

V5

Point 5 Volts.

v_ar5: Option<i16>

VAr5

Point 5 VARs.

v6: Option<u16>

V6

Point 6 Volts.

v_ar6: Option<i16>

VAr6

Point 6 VARs.

v7: Option<u16>

V7

Point 7 Volts.

v_ar7: Option<i16>

VAr7

Point 7 VARs.

v8: Option<u16>

V8

Point 8 Volts.

v_ar8: Option<i16>

VAr8

Point 8 VARs.

v9: Option<u16>

V9

Point 9 Volts.

v_ar9: Option<i16>

VAr9

Point 9 VARs.

v10: Option<u16>

V10

Point 10 Volts.

v_ar10: Option<i16>

VAr10

Point 10 VARs.

v11: Option<u16>

V11

Point 11 Volts.

v_ar11: Option<i16>

VAr11

Point 11 VARs.

v12: Option<u16>

V12

Point 12 Volts.

v_ar12: Option<i16>

VAr12

Point 12 VARs.

v13: Option<u16>

V13

Point 13 Volts.

v_ar13: Option<i16>

VAr13

Point 13 VARs.

v14: Option<u16>

V14

Point 14 Volts.

v_ar14: Option<i16>

VAr14

Point 14 VARs.

v15: Option<u16>

V15

Point 15 Volts.

v_ar15: Option<i16>

VAr15

Point 15 VARs.

v16: Option<u16>

V16

Point 16 Volts.

v_ar16: Option<i16>

VAr16

Point 16 VARs.

v17: Option<u16>

V17

Point 17 Volts.

v_ar17: Option<i16>

VAr17

Point 17 VARs.

v18: Option<u16>

V18

Point 18 Volts.

v_ar18: Option<i16>

VAr18

Point 18 VARs.

v19: Option<u16>

V19

Point 19 Volts.

v_ar19: Option<i16>

VAr19

Point 19 VARs.

v20: Option<u16>

V20

Point 20 Volts.

v_ar20: Option<i16>

VAr20

Point 20 VARs.

crv_nam: Option<String>

CrvNam

Optional description for curve. (Max 16 chars)

rmp_tms: Option<u16>

RmpTms

The time of the PT1 in seconds (time to accomplish a change of 95%).

rmp_dec_tmm: Option<u16>

RmpDecTmm

The maximum rate at which the VAR value may be reduced in response to changes in the voltage value. %refVal is %WMax %VArMax or %VArAval depending on value of DeptRef.

rmp_inc_tmm: Option<u16>

RmpIncTmm

The maximum rate at which the VAR value may be increased in response to changes in the voltage value. %refVal is %WMax %VArMax or %VArAval depending on value of DeptRef.

read_only: CurveReadOnly

ReadOnly

Boolean flag indicates if curve is read-only or can be modified.

Implementations

Source

impl Curve

pub const ACT_PT: Point<Self, u16>

pub const DEPT_REF: Point<Self, CurveDeptRef>

pub const V1: Point<Self, u16>

pub const V_AR1: Point<Self, i16>

pub const V2: Point<Self, Option<u16>>

pub const V_AR2: Point<Self, Option<i16>>

pub const V3: Point<Self, Option<u16>>

pub const V_AR3: Point<Self, Option<i16>>

pub const V4: Point<Self, Option<u16>>

pub const V_AR4: Point<Self, Option<i16>>

pub const V5: Point<Self, Option<u16>>

pub const V_AR5: Point<Self, Option<i16>>

pub const V6: Point<Self, Option<u16>>

pub const V_AR6: Point<Self, Option<i16>>

pub const V7: Point<Self, Option<u16>>

pub const V_AR7: Point<Self, Option<i16>>

pub const V8: Point<Self, Option<u16>>

pub const V_AR8: Point<Self, Option<i16>>

pub const V9: Point<Self, Option<u16>>

pub const V_AR9: Point<Self, Option<i16>>

pub const V10: Point<Self, Option<u16>>

pub const V_AR10: Point<Self, Option<i16>>

pub const V11: Point<Self, Option<u16>>

pub const V_AR11: Point<Self, Option<i16>>

pub const V12: Point<Self, Option<u16>>

pub const V_AR12: Point<Self, Option<i16>>

pub const V13: Point<Self, Option<u16>>

pub const V_AR13: Point<Self, Option<i16>>

pub const V14: Point<Self, Option<u16>>

pub const V_AR14: Point<Self, Option<i16>>

pub const V15: Point<Self, Option<u16>>

pub const V_AR15: Point<Self, Option<i16>>

pub const V16: Point<Self, Option<u16>>

pub const V_AR16: Point<Self, Option<i16>>

pub const V17: Point<Self, Option<u16>>

pub const V_AR17: Point<Self, Option<i16>>

pub const V18: Point<Self, Option<u16>>

pub const V_AR18: Point<Self, Option<i16>>

pub const V19: Point<Self, Option<u16>>

pub const V_AR19: Point<Self, Option<i16>>

pub const V20: Point<Self, Option<u16>>

pub const V_AR20: Point<Self, Option<i16>>

pub const CRV_NAM: Point<Self, Option<String>>

pub const RMP_TMS: Point<Self, Option<u16>>

pub const RMP_DEC_TMM: Point<Self, Option<u16>>

pub const RMP_INC_TMM: Point<Self, Option<u16>>

pub const READ_ONLY: Point<Self, CurveReadOnly>