pub enum ArGraMod {
Edge,
Center,
Invalid(u16),
}Available on crate feature
model128 only.Expand description
ArGraMod
Indicates if gradients trend toward zero at the edges of the deadband or trend toward zero at the center of the deadband.
Variants