DerEnterService

Struct DerEnterService 

pub struct DerEnterService {
    pub es: Option<Es>,
    pub esv_hi: Option<u16>,
    pub esv_lo: Option<u16>,
    pub es_hz_hi: Option<u32>,
    pub es_hz_lo: Option<u32>,
    pub es_dly_tms: Option<u32>,
    pub es_rnd_tms: Option<u32>,
    pub es_rmp_tms: Option<u32>,
    pub es_dly_rem_tms: Option<u32>,
    pub v_sf: Option<i16>,
    pub hz_sf: Option<i16>,
}
Available on crate feature model703 only.
Enter Service

Enter service model.

Fields

es: Option<Es>

Permit Enter Service

Permit enter service.

esv_hi: Option<u16>

Enter Service Voltage High

Enter service voltage high threshold as percent of normal voltage.

esv_lo: Option<u16>

Enter Service Voltage Low

Enter service voltage low threshold as percent of normal voltage.

es_hz_hi: Option<u32>

Enter Service Frequency High

Enter service frequency high threshold.

es_hz_lo: Option<u32>

Enter Service Frequency Low

Enter service frequency low threshold.

es_dly_tms: Option<u32>

Enter Service Delay Time

Enter service delay time in seconds.

es_rnd_tms: Option<u32>

Enter Service Random Delay

Enter service random delay in seconds.

es_rmp_tms: Option<u32>

Enter Service Ramp Time

Enter service ramp time in seconds.

es_dly_rem_tms: Option<u32>

Enter Service Delay Remaining

Enter service delay time remaining in seconds.

v_sf: Option<i16>

Voltage Scale Factor

Voltage percentage scale factor.

hz_sf: Option<i16>

Frequency Scale Factor

Frequency scale factor.

Implementations

Source

impl DerEnterService

pub const ES: Point<Self, Option<Es>>

pub const ESV_HI: Point<Self, Option<u16>>

pub const ESV_LO: Point<Self, Option<u16>>

pub const ES_HZ_HI: Point<Self, Option<u32>>

pub const ES_HZ_LO: Point<Self, Option<u32>>

pub const ES_DLY_TMS: Point<Self, Option<u32>>

pub const ES_RND_TMS: Point<Self, Option<u32>>

pub const ES_RMP_TMS: Point<Self, Option<u32>>

pub const ES_DLY_REM_TMS: Point<Self, Option<u32>>

pub const V_SF: Point<Self, Option<i16>>

pub const HZ_SF: Point<Self, Option<i16>>