Enum Fmt
Source pub enum Fmt {
None,
X509Pem,
X509Der,
Invalid(u16),
}
Available on crate feature model8 only.
Format
X.509 format of the certificate. DER or PEM.
Raw enum value not defined by the SunSpec model.
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
The sentinel used for optional enum points.
The integer representation used on the wire.
Convert a raw representation into an enum value.
Convert an enum value into its raw representation.
The size of this value
The value when the point is not supported.
Check whether the decoded value is the SunSpec invalid sentinel.
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.
Decode value from a given slice of u16
Encode value into a u16 array