Model9

Struct Model9 

pub struct Model9 {
Show 92 fields pub cert_uid: u16, pub cert_role: u16, pub fmt: Fmt, pub typ: Typ, pub tot_ln: u16, pub frg_ln: u16, pub frg1: u16, pub frg2: u16, pub frg3: u16, pub frg4: u16, pub frg5: u16, pub frg6: u16, pub frg7: u16, pub frg8: u16, pub frg9: u16, pub frg10: u16, pub frg11: u16, pub frg12: u16, pub frg13: u16, pub frg14: u16, pub frg15: u16, pub frg16: u16, pub frg17: u16, pub frg18: u16, pub frg19: u16, pub frg20: u16, pub frg21: u16, pub frg22: u16, pub frg23: u16, pub frg24: u16, pub frg25: u16, pub frg26: u16, pub frg27: u16, pub frg28: u16, pub frg29: u16, pub frg30: u16, pub frg31: u16, pub frg32: u16, pub frg33: u16, pub frg34: u16, pub frg35: u16, pub frg36: u16, pub frg37: u16, pub frg38: u16, pub frg39: u16, pub frg40: u16, pub frg41: u16, pub frg42: u16, pub frg43: u16, pub frg44: u16, pub frg45: u16, pub frg46: u16, pub frg47: u16, pub frg48: u16, pub frg49: u16, pub frg50: u16, pub frg51: u16, pub frg52: u16, pub frg53: u16, pub frg54: u16, pub frg55: u16, pub frg56: u16, pub frg57: u16, pub frg58: u16, pub frg59: u16, pub frg60: u16, pub frg61: u16, pub frg62: u16, pub frg63: u16, pub frg64: u16, pub frg65: u16, pub frg66: u16, pub frg67: u16, pub frg68: u16, pub frg69: u16, pub frg70: u16, pub frg71: u16, pub frg72: u16, pub frg73: u16, pub frg74: u16, pub frg75: u16, pub frg78: u16, pub frg79: u16, pub frg80: u16, pub ts: u32, pub ms: u16, pub seq: u16, pub uid: u16, pub role: u16, pub alg: Alg, pub n: u16, pub repeating: Vec<Repeating>,
}
Available on crate feature model9 only.
Set Operator Security Certificate

Security model for PKI

Fields

cert_uid: u16

Cert_UID

User ID for this certificate

cert_role: u16

Cert_Role

Role for this certificate

fmt: Fmt

Format

Format of this certificate

typ: Typ

Type

Type of this certificate

tot_ln: u16

Total Length

Total Length of the Certificate

Detail: In registers, zero padded.

frg_ln: u16

Fragment length

Length of this fragment

Detail: Maximum fragment length is 80 registers

frg1: u16

Frag1

First word of this fragment

frg2: u16frg3: u16frg4: u16frg5: u16frg6: u16frg7: u16frg8: u16frg9: u16frg10: u16frg11: u16frg12: u16frg13: u16frg14: u16frg15: u16frg16: u16frg17: u16frg18: u16frg19: u16frg20: u16frg21: u16frg22: u16frg23: u16frg24: u16frg25: u16frg26: u16frg27: u16frg28: u16frg29: u16frg30: u16frg31: u16frg32: u16frg33: u16frg34: u16frg35: u16frg36: u16frg37: u16frg38: u16frg39: u16frg40: u16frg41: u16frg42: u16frg43: u16frg44: u16frg45: u16frg46: u16frg47: u16frg48: u16frg49: u16frg50: u16frg51: u16frg52: u16frg53: u16frg54: u16frg55: u16frg56: u16frg57: u16frg58: u16frg59: u16frg60: u16frg61: u16frg62: u16frg63: u16frg64: u16frg65: u16frg66: u16frg67: u16frg68: u16frg69: u16frg70: u16frg71: u16frg72: u16frg73: u16frg74: u16frg75: u16frg78: u16frg79: u16frg80: u16

Frag80

Last word of this fragment

ts: u32

Timestamp

Timestamp value is the number of seconds since January 1, 2000

ms: u16

Milliseconds

Millisecond counter 0-999

seq: u16

Sequence

Sequence number of request

Detail: Shall be advanced for each request

uid: u16

UID

User ID for the request signature

role: u16

Role

Signing key used 0-5

Detail: Each controller is assigned a key index that maps to their access control role

alg: Alg

Algorithm

Algorithm used to compute the digital signature

Detail: For future proof

n: u16

N

Number of registers to follow for the certificate

repeating: Vec<Repeating>

Implementations

Source

impl Model9

pub const CERT_UID: Point<Self, u16>

pub const CERT_ROLE: Point<Self, u16>

pub const FMT: Point<Self, Fmt>

pub const TYP: Point<Self, Typ>

pub const TOT_LN: Point<Self, u16>

pub const FRG_LN: Point<Self, u16>

pub const FRG1: Point<Self, u16>

pub const FRG2: Point<Self, u16>

pub const FRG3: Point<Self, u16>

pub const FRG4: Point<Self, u16>

pub const FRG5: Point<Self, u16>

pub const FRG6: Point<Self, u16>

pub const FRG7: Point<Self, u16>

pub const FRG8: Point<Self, u16>

pub const FRG9: Point<Self, u16>

pub const FRG10: Point<Self, u16>

pub const FRG11: Point<Self, u16>

pub const FRG12: Point<Self, u16>

pub const FRG13: Point<Self, u16>

pub const FRG14: Point<Self, u16>

pub const FRG15: Point<Self, u16>

pub const FRG16: Point<Self, u16>

pub const FRG17: Point<Self, u16>

pub const FRG18: Point<Self, u16>

pub const FRG19: Point<Self, u16>

pub const FRG20: Point<Self, u16>

pub const FRG21: Point<Self, u16>

pub const FRG22: Point<Self, u16>

pub const FRG23: Point<Self, u16>

pub const FRG24: Point<Self, u16>

pub const FRG25: Point<Self, u16>

pub const FRG26: Point<Self, u16>

pub const FRG27: Point<Self, u16>

pub const FRG28: Point<Self, u16>

pub const FRG29: Point<Self, u16>

pub const FRG30: Point<Self, u16>

pub const FRG31: Point<Self, u16>

pub const FRG32: Point<Self, u16>

pub const FRG33: Point<Self, u16>

pub const FRG34: Point<Self, u16>

pub const FRG35: Point<Self, u16>

pub const FRG36: Point<Self, u16>

pub const FRG37: Point<Self, u16>

pub const FRG38: Point<Self, u16>

pub const FRG39: Point<Self, u16>

pub const FRG40: Point<Self, u16>

pub const FRG41: Point<Self, u16>

pub const FRG42: Point<Self, u16>

pub const FRG43: Point<Self, u16>

pub const FRG44: Point<Self, u16>

pub const FRG45: Point<Self, u16>

pub const FRG46: Point<Self, u16>

pub const FRG47: Point<Self, u16>

pub const FRG48: Point<Self, u16>

pub const FRG49: Point<Self, u16>

pub const FRG50: Point<Self, u16>

pub const FRG51: Point<Self, u16>

pub const FRG52: Point<Self, u16>

pub const FRG53: Point<Self, u16>

pub const FRG54: Point<Self, u16>

pub const FRG55: Point<Self, u16>

pub const FRG56: Point<Self, u16>

pub const FRG57: Point<Self, u16>

pub const FRG58: Point<Self, u16>

pub const FRG59: Point<Self, u16>

pub const FRG60: Point<Self, u16>

pub const FRG61: Point<Self, u16>

pub const FRG62: Point<Self, u16>

pub const FRG63: Point<Self, u16>

pub const FRG64: Point<Self, u16>

pub const FRG65: Point<Self, u16>

pub const FRG66: Point<Self, u16>

pub const FRG67: Point<Self, u16>

pub const FRG68: Point<Self, u16>

pub const FRG69: Point<Self, u16>

pub const FRG70: Point<Self, u16>

pub const FRG71: Point<Self, u16>

pub const FRG72: Point<Self, u16>

pub const FRG73: Point<Self, u16>

pub const FRG74: Point<Self, u16>

pub const FRG75: Point<Self, u16>

pub const FRG78: Point<Self, u16>

pub const FRG79: Point<Self, u16>

pub const FRG80: Point<Self, u16>

pub const TS: Point<Self, u32>

pub const MS: Point<Self, u16>

pub const SEQ: Point<Self, u16>

pub const UID: Point<Self, u16>

pub const ROLE: Point<Self, u16>

pub const ALG: Point<Self, Alg>

pub const N: Point<Self, u16>